#include "../realm.h"


uint32_t realm_first_pkt_len()
{
    return 0;
};


int32_t realm_decide_remote_idx(int32_t idx, const char *buf)
{
    return 0;
};
